Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FetchAttestationBundle ¶
FetchAttestationBundle fetches the sigstore bundle from a repo for a given repo and EIF hash
func FetchDigest ¶ added in v0.1.10
FetchDigest fetches the attestation digest for a given repo and tag
func FetchLatestDigest ¶ added in v0.0.17
FetchLatestDigest gets the latest release, tag, and attestation digest of a repo
func FetchLatestTag ¶ added in v0.1.13
FetchLatestTag fetches the latest tag for a repo
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.