github

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 19, 2025 License: AGPL-3.0 Imports: 6 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FetchAttestationBundle

func FetchAttestationBundle(repo, digest string) ([]byte, error)

FetchAttestationBundle fetches the sigstore bundle from a repo for a given repo and EIF hash

func FetchDigest added in v0.1.10

func FetchDigest(repo, tag string) (string, error)

FetchDigest fetches the attestation digest for a given repo and tag

func FetchLatestDigest added in v0.0.17

func FetchLatestDigest(repo string) (string, error)

FetchLatestDigest gets the latest release, tag, and attestation digest of a repo

func FetchLatestTag added in v0.1.13

func FetchLatestTag(repo string) (string, error)

FetchLatestTag fetches the latest tag for a repo

Types

This section is empty.

Jump to