github

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2025 License: AGPL-3.0 Imports: 7 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FetchAttestationBundle

func FetchAttestationBundle(repo, digest string) ([]byte, error)

FetchAttestationBundle fetches the sigstore bundle from a repo for a given repo and EIF hash

func FetchLatestDigest added in v0.0.17

func FetchLatestDigest(repo string) (string, error)

FetchLatestDigest gets the latest release and attestation digest of a repo

Types

This section is empty.

Jump to